@@ -9,10 +9,10 @@ def update_bind_status(database, bind_address, bind_status):
 
     LOG.debug("Update {} bind {} with status {}".format(database, bind_address, bind_status))
 
-    if bind_address == CREATING:
-        bind_address = CREATED
+    if bind_status == CREATING:
+        bind_status = CREATED
     else:
-        bind_address = ERROR
+        bind_status = ERROR
 
     bind = DatabaseBind.objects.get(database= database, bind_address= bind_address)
     instances = database.infra.instances.all()
